# README

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

## ibm-iis-kafka

Re-usable functions for interacting with IBM InfoSphere Information Server's Kafka event mechanism

**Examples**

```javascript
const iiskafka = require('ibm-iis-kafka');
const infosphereEventEmitter = new iiskafka.InfosphereEventEmitter('zookeeper-host:2181', 'asset-object-handler', false);
infosphereEventEmitter.on('IGC_DATABASESGROUP_EVENT', function(infosphereEvent, eventCtx, commitCallback) {
  console.log("Processing a change to a Database object:");
  console.log("  ... type (display name): " + infosphereEvent.ASSET_TYPE);
  console.log("  ... unique ID (RID)    : " + infosphereEvent.ASSET_RID);
  console.log("  ... parent identity    : " + infosphereEvent.ASSET_CONTEXT);
  console.log("  ... asset identity     : " + infosphereEvent.ASSET_NAME);
  console.log("  ... action taken       : " + infosphereEvent.ACTION);
  console.log("Full event: " + JSON.stringify(infosphereEvent));
  commitCallback(eventCtx); // tell Kafka we've successfully consumed this event
});
```

**Meta**

-   **license**: Apache-2.0

## InfosphereEventEmitter

Connects to Kafka on the specified system and emits any events raised, based on their eventType

**Parameters**

-   `zookeeperConnection` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** the hostname of the domain (services) tier of the Information Server environment and port number to connect to Zookeeper service (e.g. hostname:52181)
-   `handlerId` **[string](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String)** a unique identity for the handler (allowing multiple handlers to consume the same events)
-   `bFromBeginning` **[boolean](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Boolean)?** if true, process all events from the beginning of tracking in Information Server

## eventCommitCallback

This callback is invoked as in order to commit that an event was successfully consumed from Kafka

Type: [Function](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Statements/function)

**Parameters**

-   `eventCtx` **[Object](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object)** the context of the Kafka event that was consumed
